summaryrefslogtreecommitdiff
path: root/lisp/org
diff options
context:
space:
mode:
authorStefan Kangas <stefankangas@gmail.com>2022-10-01 17:16:03 +0200
committerStefan Kangas <stefankangas@gmail.com>2022-10-01 17:16:03 +0200
commit55f46cc77cb9d72fbabadb63d8aeab45c5e005e2 (patch)
tree92abe51fc09886a1eda8f4a6c8d1602aba604c25 /lisp/org
parentabe83f76de36bc3922b410f9872065fc3903738b (diff)
downloademacs-55f46cc77cb9d72fbabadb63d8aeab45c5e005e2.tar.gz
emacs-55f46cc77cb9d72fbabadb63d8aeab45c5e005e2.tar.bz2
emacs-55f46cc77cb9d72fbabadb63d8aeab45c5e005e2.zip
Decrease use of the word "Emacsen" in docs
"Emacsen" is either a less clear way of saying "old versions of Emacs", or an implicit reference to XEmacs. We recommend against using it in the FAQ. So use the more clear wording instead. * doc/misc/gnus.texi (Oort Gnus): * doc/misc/widget.texi (Basic Types, toggle): * lisp/cedet/semantic/bovine/c.el (semantic-c-skip-conditional-section): * lisp/cedet/semantic/wisent/comp.el (wisent-compile-grammar): * lisp/desktop.el (desktop-save): * lisp/erc/erc-compat.el: * lisp/erc/erc-log.el: * lisp/gnus/gnus-util.el (gnus-replace-in-string): * lisp/mail/footnote.el: * lisp/net/tramp-archive.el: * lisp/net/tramp-smb.el: * lisp/net/tramp-uu.el: * lisp/net/tramp.el: (with-tramp-locked-connection): * lisp/org/ol-eww.el: * lisp/org/org-compat.el: (org-define-error): * lisp/shadowfile.el: * lisp/winner.el: Don't use the word "Emacsen".
Diffstat (limited to 'lisp/org')
-rw-r--r--lisp/org/ol-eww.el2
-rw-r--r--lisp/org/org-compat.el4
2 files changed, 3 insertions, 3 deletions
diff --git a/lisp/org/ol-eww.el b/lisp/org/ol-eww.el
index d1bb5195107..0bd1b5b926c 100644
--- a/lisp/org/ol-eww.el
+++ b/lisp/org/ol-eww.el
@@ -48,7 +48,7 @@
(require 'cl-lib)
(require 'eww)
-;; For Emacsen < 25.
+;; For Emacs < 25.
(defvar eww-current-title)
(defvar eww-current-url)
diff --git a/lisp/org/org-compat.el b/lisp/org/org-compat.el
index 15f0daa91ae..bbad4ae635d 100644
--- a/lisp/org/org-compat.el
+++ b/lisp/org/org-compat.el
@@ -1,4 +1,4 @@
;;; org-compat.el --- Compatibility Code for Older Emacsen -*- lexical-binding: t; -*-
;; Copyright (C) 2004-2022 Free Software Foundation, Inc.
@@ -929,7 +929,7 @@ Pass COLUMN and FORCE to `move-to-column'."
"Define NAME as a new error signal.
MESSAGE is a string that will be output to the echo area if such
an error is signaled without being caught by a `condition-case'.
-Implements `define-error' for older emacsen."
+Implements `define-error' for older versions of Emacs."
(if (fboundp 'define-error) (define-error name message)
(put name 'error-conditions
(copy-sequence (cons name (get 'error 'error-conditions))))))
@@ -1,4 +1,4 @@
-;;; org-compat.el --- Compatibility Code for Older Emacsen -*- lexical-binding: t; -*-
+;;; org-compat.el --- Compatibility Code for Older Emacs -*- lexical-binding: t; -*-
;; Copyright (C) 2004-2022 Free Software Foundation, Inc.